bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.plates
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: WrapToGaussianGamma.plates